/*
 * Copyright (C) 2004 Nathan Lutchansky <lutchann@litech.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <sys/types.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <pthread.h>

#include <event.h>
#include <frame.h>
#include <stream.h>
#include <inputs.h>
#include <encoders.h>
#include <filters.h>
#include <outputs.h>
#include <rtp.h>
#include <conf_parse.h>
#include <config.h>

int read_config_file( void );

static void init_random(void)
{
	int fd;
	unsigned int seed;

	if( ( fd = open( "/dev/urandom", O_RDONLY ) ) < 0 )
	{
		perror( "open /dev/random" );
		exit( 1 );
	}
	if( read( fd, &seed, sizeof( seed ) ) < 0 )
	{
		perror( "read /dev/urandom" );
		exit( 1 );
	}
	close( fd );
	srandom( seed );
}

void random_bytes( unsigned char *dest, int len )
{
	int i;

	for( i = 0; i < len; ++i )
		dest[i] = random() & 0xff;
}

int main( int argc, char **argv )
{
	init_random();

	v4l_init();
#ifdef SPOOK_INPUT_DC1394
	dc1394_init();
#endif
#ifdef SPOOK_ENCODER_JPEG
	jpeg_init();
#endif
	framedrop_init();
#ifdef SPOOK_ENCODER_MPEG4
	mpeg4_init();
	rtp_mpeg4_init();
#endif
	http_init();

	if( read_config_file() < 0 ) return 1;

	event_loop( 0 );

	return 0;
}

/********************* GLOBAL CONFIGURATION DIRECTIVES ********************/

int config_frameheap( int num_tokens, struct token *tokens, void *d )
{
	int size, count;

	count = tokens[1].v.num;
	if( num_tokens == 3 ) size = tokens[2].v.num;
	else size = 352*288*3;

	printf( "size is %d\n", size );

	if( count < 10 )
	{
		printf( "frame heap of %d frames is too small, use at least 10\n",
				count );
		return -1;
	}

	init_frame_heap( size, count );

	return 0;
}

